@@ -8,8 +8,11 @@ impl PeekParsers for ParsersImpl {
   where
     A: Debug + 'a, {
     Parser::new(move |parse_state| match parser.run(parse_state) {
-      ParseResult::Success { get, .. } => ParseResult::successful(get, 0),
-      ParseResult::Failure { get, is_committed } => ParseResult::failed(get, is_committed),
+      ParseResult::Success { value, .. } => ParseResult::successful(value, 0),
+      ParseResult::Failure {
+        error,
+        committed_status: is_committed,
+      } => ParseResult::failed(error, is_committed),
     })
   }
 }
